@@ -230,7 +230,6 @@ void changetextscale(float newscale)
 
 /*--------------------------------------------------------------*/
 /* Auto-scale the drawing to fit the declared page size.	*/
-/* (for now, with fixed 1" margins)				*/
 /*								*/
 /* If the page is declared encapsulated, then do nothing.	*/
 /* If a frame box is on the page, then scale to fit the frame	*/
@@ -242,7 +241,6 @@ void autoscale(int page)
    float newxscale, newyscale;
    float scalefudge = (xobjs.pagelist[page]->coordstyle
 	== CM) ? CMSCALE : INCHSCALE;
-   float margin = 144.0;
    int width, height;
    polyptr framebox;
 
@@ -252,10 +250,10 @@ void autoscale(int page)
       return;
    }
 
-   newxscale = (xobjs.pagelist[page]->pagesize.x - margin)
-	/ scalefudge;
-   newyscale = (xobjs.pagelist[page]->pagesize.y - margin)
-	/ scalefudge;
+   newxscale = (xobjs.pagelist[page]->pagesize.x -
+	(2 * xobjs.pagelist[page]->margins.x)) / scalefudge;
+   newyscale = (xobjs.pagelist[page]->pagesize.y -
+	(2 * xobjs.pagelist[page]->margins.y)) / scalefudge;
 
    if ((framebox = checkforbbox(topobject)) != NULL) {
       int i, minx, miny, maxx, maxy;
@@ -628,7 +626,7 @@ void togglegrid(u_short type)
       "internal units", NULL
    };
 
-   XcFakeTagCall(xcinterp, 3, "config", "coordstyle", stylenames[type]);
+   XcInternalTagCall(xcinterp, 3, "config", "coordstyle", stylenames[type]);
 }
 
 #endif /* TCL_WRAPPER */
@@ -842,8 +840,10 @@ void setcolormark(int colorval)
 	 }
    }
 
-   XcFakeTagCall(xcinterp, 3, "color", "set", (colorval == DEFAULTCOLOR) ?
+#ifdef TCL_WRAPPER
+   XcInternalTagCall(xcinterp, 3, "color", "set", (colorval == DEFAULTCOLOR) ?
 	"inherit" : cstr);
+#endif
 }
 
 /*----------------------------------------------------------------*/
@@ -887,13 +887,13 @@ void setallstylemarks(u_short styleval)
 	 break;
    }
 
-   XcFakeTagCall(xcinterp, 3, "fill", fstr,
+   XcInternalTagCall(xcinterp, 3, "fill", fstr,
 		(styleval & OPAQUE) ? "opaque" : "transparent");
-   XcFakeTagCall(xcinterp, 3, "border", "bbox", (styleval & BBOX) ? "true" :
+   XcInternalTagCall(xcinterp, 3, "border", "bbox", (styleval & BBOX) ? "true" :
 		"false");
-   XcFakeTagCall(xcinterp, 2, "border", (styleval & UNCLOSED) ? "unclosed" :
+   XcInternalTagCall(xcinterp, 2, "border", (styleval & UNCLOSED) ? "unclosed" :
 		"closed");
-   XcFakeTagCall(xcinterp, 2, "border", bptr);
+   XcInternalTagCall(xcinterp, 2, "border", bptr);
 }
 
 #endif /* TCL_WRAPPER */
@@ -1094,6 +1094,7 @@ void setcolor(xcWidget w, int cindex)
       if (eventmode != TEXT_MODE && eventmode != ETEXT_MODE)
          areawin->color = cval;      
    }
+   else pwriteback(areawin->topinstance);
 }
 
 /*--------------------------------------------------------------*/
@@ -1103,7 +1104,7 @@ void setcolor(xcWidget w, int cindex)
 void togglefontmark(int fontval)
 {
    if (fonts[fontval].family != NULL)
-      XcFakeTagCall(xcinterp, 3, "label", "family", fonts[fontval].family);
+      XcInternalTagCall(xcinterp, 3, "label", "family", fonts[fontval].family);
 }
 
 /*------------------------------------------------------*/
@@ -1115,7 +1116,7 @@ void togglestylemark(int styleval)
 {
    char *cstyle = translatestyle(styleval);
    if (cstyle != NULL)
-      XcFakeTagCall(xcinterp, 3, "label", "style", cstyle);
+      XcInternalTagCall(xcinterp, 3, "label", "style", cstyle);
 }
 
 /*------------------------------------------------------*/
@@ -1126,7 +1127,7 @@ void toggleencodingmark(int encodingval)
 {
    char *cenc = translateencoding(encodingval);
    if (cenc != NULL)
-      XcFakeTagCall(xcinterp, 3, "label", "encoding", cenc);
+      XcInternalTagCall(xcinterp, 3, "label", "encoding", cenc);
 }
 
 /*------------------------------------------------------*/
@@ -1135,14 +1136,14 @@ void toggleencodingmark(int encodingval)
 
 void togglejustmarks(int justvalue)
 {
-   XcFakeTagCall(xcinterp, 4, "label", "justify", (justvalue & RIGHT) ? "right" :
+   XcInternalTagCall(xcinterp, 4, "label", "justify", (justvalue & RIGHT) ? "right" :
 	(justvalue & NOTLEFT) ? "center" : "left",
 	(justvalue & TOP) ? "top" : (justvalue & NOTBOTTOM) ? "middle" : "bottom");
-   XcFakeTagCall(xcinterp, 3, "label", "flipinvariant", (justvalue & FLIPINV) ?
+   XcInternalTagCall(xcinterp, 3, "label", "flipinvariant", (justvalue & FLIPINV) ?
 	"true" : "false");
-   XcFakeTagCall(xcinterp, 3, "label", "latex", (justvalue & LATEXLABEL) ?
+   XcInternalTagCall(xcinterp, 3, "label", "latex", (justvalue & LATEXLABEL) ?
 	"true" : "false");
-   XcFakeTagCall(xcinterp, 3, "label", "visible", (justvalue & PINVISIBLE) ?
+   XcInternalTagCall(xcinterp, 3, "label", "visible", (justvalue & PINVISIBLE) ?
 	"true" : "false");
 }
 
