@@ -503,8 +503,9 @@ enum loadmodes {IMPORT = 1, PSBKGROUND, SCRIPT, RECOVER,
 #define INDEPENDENT	0
 #define DEPENDENT	1
 #define TOTAL_PAGES	2
-#define PAGE_DEPEND	3
-#define ALL_PAGES	4
+#define LINKED_PAGES	3
+#define PAGE_DEPEND	4
+#define ALL_PAGES	5
 
 /*----------------------------------------------------------------------*/
 /* Color scheme styles (other than NORMAL)				*/
@@ -619,6 +620,7 @@ typedef struct _eparam *eparamptr;
 
 typedef struct _eparam {
    char *	key;	    /* name of the parameter */
+   u_char	flags;	    /* namely, bit declaring an indirect parameter */
    union {
       int	pointno;    /* point number in point array, for polygons */
       short	pathpt[2];  /* element number and point number, for paths */
@@ -627,6 +629,8 @@ typedef struct _eparam {
    eparamptr	next;	    /* next parameter in linked list */
 } eparam;
 
+#define P_INDIRECT	0x01	/* indirect parameter indicator */
+
 /*----------------------------------------------------------------------*/
 /* Generic element type	is a superset of all elements.			*/	
 /*----------------------------------------------------------------------*/
@@ -1068,7 +1072,6 @@ typedef struct _alias {
 #ifndef ClientData
    #define ClientData			XtPointer
 #endif
-
 #endif
 
 /*----------------------------------------------------------------------*/
@@ -1295,6 +1298,7 @@ typedef struct {
    short	coordstyle;
    XPoint	drawingscale;
    XPoint	pagesize;	/* size of page to print on */
+   XPoint	margins;
 } Pagedata;
 
 /*----------------------------------------------------------------------*/
@@ -1423,6 +1427,7 @@ typedef struct _Technology {
 #define LIBRARY_READONLY	0x02
 #define LIBRARY_REPLACE		0x04	/* Replace instances when reading */
 #define LIBRARY_REPLACE_TEMP	0x08	/* Temporary store */
+#define LIBRARY_USED		0x10	/* Temporary marker flag */
 
 /*----------------------------------------------------------------------*/
 /* A convenient structure for holding all the object lists		*/
